@@ -1833,38 +1833,48 @@ class BasicDataApi(metaclass=Singleton):
         except Exception as e:
             print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
 
-    def get_north_cap_data(self, begin_date, end_date, time_para):
+    def get_north_cap_data(self, begin_date, end_date, time_para, index_id):
         try:
             raw_api = RawDataApi()
             begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
-            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hs300'])
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=[index_id])
+            index_info = self.get_index_info(index_list=[index_id])
+            desc_name = index_info.set_index('index_id').to_dict()['desc_name']
+            desc_name['north_cap'] = '北向资金'
             north_cap = raw_api.get_north_cap(begin_date, end_date)
             index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
             north_cap =north_cap.set_index('datetime')[['north_cap']]
-            df = index_price.join(north_cap).rename(columns={'hs300':'沪深300','north_cap':'北向资金'})
+            df = index_price.join(north_cap).rename(columns=desc_name)
             return df
         except Exception as e:
             print(f'failed to asset price <err_msg> {e} from basic.get_north_cap_data')
 
-    def get_south_cap_data(self, begin_date, end_date, time_para):
+    def get_south_cap_data(self, begin_date, end_date, time_para, index_id):
         try:
             raw_api = RawDataApi()
             begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
-            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hsi'])
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=[index_id])
+            index_info = self.get_index_info(index_list=[index_id])
+            desc_name = index_info.set_index('index_id').to_dict()['desc_name']
+            desc_name['south_cap'] = '南下资金'
             north_cap = raw_api.get_south_cap(begin_date, end_date)
             index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
             north_cap =north_cap.set_index('datetime')[['south_cap']]
-            df = index_price.join(north_cap).rename(columns={'hsi':'恒生指数','south_cap':'南下资金'})
+            df = index_price.join(north_cap).rename(columns=desc_name)
             return df
         except Exception as e:
             print(f'failed to asset price <err_msg> {e} from basic.get_south_cap_data')
 
-    def get_side_cap_data(self, direction, begin_date, end_date, time_para):
+    def get_side_cap_index(self):
+        index_list = [{'id':'sse50','name':'上证50'},{'id':'hs300','name':'沪深300'},{'id':'csi500','name':'中证500'},{'id':'csi1000','name':'中证1000'},{'id':'hsi','name':'恒生指数'}]
+        return index_list
+
+    def get_side_cap_data(self, direction, begin_date, end_date, time_para, index_id):
         try:
             if direction == '北向资金':
-                return self.get_north_cap_data(begin_date, end_date, time_para)
+                return self.get_north_cap_data(begin_date, end_date, time_para, index_id)
             else:
-                return self.get_south_cap_data(begin_date, end_date, time_para)
+                return self.get_south_cap_data(begin_date, end_date, time_para, index_id)
         except Exception as e:
             print(f'failed to asset price <err_msg> {e} from basic.get_side_cap_data')
 
@@ -1873,10 +1883,10 @@ class BasicDataApi(metaclass=Singleton):
             raw = RawDataApi()
             begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
             df = raw.get_em_macroeconomic_monthly(codes=['PPI'],start_date=begin_date,end_date=end_date)
-            df = df.drop(columns=['_update_time','codes']).rename(columns={'datetime':'日期','value':'同比'})
+            df = df.drop(columns=['_update_time','codes']).rename(columns={'datetime':'datetime','value':'同比'})
             df.loc[:,'总增长'] = df.同比.cumsum()
             index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hs300'])
-            index_price = index_price.set_index('datetime')[['close']].loc[df.日期.values[0]:df.日期.values[-1]]
+            index_price = index_price.set_index('datetime')[['close']].loc[df.datetime.values[0]:df.datetime.values[-1]]
             index_ret = round(index_price.close[-1] / index_price.close[0] - 1,3)
             text = ['反映一定时期内全部工业产品出厂价格总水平的变动趋势和变动幅度的相对数。',
                     '衡量工业企业产品出厂价格变动趋势和变动程度的指数，是反映某一时期生产领域价格变动情况的重要经济指标。',
@@ -1907,6 +1917,7 @@ class BasicDataApi(metaclass=Singleton):
             df.loc[:,'非制造业PMI同比'] = df.非制造业PMI.rolling(window=13).apply(pct_chg)
             df.loc[:,'PMI同比'] = df.PMI.rolling(window=13).apply(pct_chg)
             df = df.loc[begin_date:end_date]
+            df.index.name = 'datetime'
             text = ['衡量一个国家制造业的 “体检表”，是制造业在生产、新订单、商品价格、存货、 雇员、订单交货、新出口订单和进口等八个方面状况的指数。',
                     'PMI指数50为荣枯分水线。PMI略大于50，说明经济在缓慢前进，PMI略小于50说明经济在慢慢走向衰退。']
             data = {
@@ -1974,8 +1985,16 @@ class BasicDataApi(metaclass=Singleton):
             index_price = BasicDataApi().get_index_price_dt(start_date=df.index[0],end_date=df.index[-1],index_list=['hs300'])
             index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
             index_price = index_price.reindex(index_price.index.union(df.index).sort_values()).ffill()
-            df = df.join(index_price).dropna().rename(columns={'hs300':'沪深300'})
-            return df.round(2)
+            df = df.join(index_price).dropna().rename(columns={'hs300':'沪深300'}).round(2)
+            text = ['消费者物价指数（consumer price index），又名居民消费价格指数，简称CPI。',
+                    '反映居民家庭购买的消费品和服务项目的价格水平变动情况，通常作为观察通货膨胀水平的重要指标。',
+                    '由以下8大类构成：食品烟酒、衣着、居住、生活用品及服务、交通和通信、教育文化和娱乐、医疗保健、其他用品和服务。',]
+            data = {
+                'data':df,
+                'text':text,
+            }
+            
+            return data
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_cpi')
             return pd.DataFrame([])
@@ -2007,7 +2026,7 @@ class BasicDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from basic.get_ah_prem')
             return pd.DataFrame([])
 
-    def get_us_bond_rate(self, begin_date, end_date, time_para, frequency):
+    def get_us_bond_rate(self, begin_date, end_date, time_para):
         try:
             rate_dic = {
                 'US_TB_10Y':'美国十年期国债收益率',
@@ -2020,7 +2039,12 @@ class BasicDataApi(metaclass=Singleton):
             us_debt = raw.get_em_macroeconomic_daily(codes=rate_dic.keys(),start_date=begin_date, end_date=end_date)
             df = us_debt.pivot_table(index='datetime',values='value',columns='codes').dropna()
             df = df.rename(columns=rate_dic)
-            return df
+            df.index.name = 'datetime'
+            data = {
+                'data':df,
+                'text':['选取美国国债名义利率']
+            }
+            return data
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_us_bond_rate')
             return pd.DataFrame([])
@@ -2031,7 +2055,11 @@ class BasicDataApi(metaclass=Singleton):
             begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
             rates = RawDataApi().get_raw_cm_index_price_df(start_date=begin_date,end_date=end_date)
             rates = rates[['datetime','usd_central_parity_rate']].rename(columns={'usd_central_parity_rate':'美元人民币汇率'})
-            return rates
+            data = {
+                'data':rates,
+                'text':['选取中美汇率中间价'],
+            }
+            return data
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_usd_index')
             return pd.DataFrame([])
\ No newline at end of file
