@@ -247,10 +247,11 @@ class DerivedDataApi(metaclass=Singleton):
                 index_info = BasicDataApi().get_index_info(index_list)
                 desc_dic = index_info.set_index('index_id').to_dict()['desc_name']
                 df = df.pivot_table(columns='index_id',values=value_col,index='datetime')
-                df.loc['中位数',:] = df.median()
-                df.loc['最大值',:] = df.max()
-                df.loc['最小值',:] = df.min()
-                df.loc['现值',:] = df.ffill().iloc[-1]
+                _df = df.copy()
+                df.loc['中位数',:] = _df.median()
+                df.loc['最大值',:] = _df.max()
+                df.loc['最小值',:] = _df.min()
+                df.loc['现值',:] = _df.ffill().iloc[-1]
                 df = df.rename(columns=desc_dic)
                 df = df.loc[['中位数','最大值','最小值','现值']].round(2)   
                 cols = df.columns.tolist()
@@ -1059,14 +1060,16 @@ class DerivedDataApi(metaclass=Singleton):
     def stock_debt_val_info(self):
         index_list = ['sse50','hs300','csi500','csi1000','gem']
         index_info = BasicDataApi().get_index_info(index_list)
-        index_info = [[r.index_id, r.desc_name] for r in index_info.itertuples()]
-        valuation_type = [['PE','风险溢价'],['DY','股息率溢价']]
-        debt_ret_list = [['TB_1Y','1年国债收益率'],['TB_3Y','3年国债收益率'],['TB_5Y','5年国债收益率'],['TB_10Y','10年国债收益率']]
-        
+        index_info = [{'id':r.index_id, 'name':r.desc_name} for r in index_info.itertuples()]
+        valuation_type = [{'id':'PE','name':'风险溢价'},{'id':'DY','name':'股息率溢价'}]
+        debt_ret_list = [   {'id':'TB_1Y','name':'1年国债收益率'},
+                            {'id':'TB_3Y','name':'3年国债收益率'},
+                            {'id':'TB_5Y','name':'5年国债收益率'},
+                            {'id':'TB_10Y','name':'10年国债收益率'}]
         data = {
-            'index_list':index_info,
-            'valuation_type':valuation_type,
-            'debt_ret_list':debt_ret_list,
+            '股指':index_info,
+            '溢价方式':valuation_type,
+            '债指':debt_ret_list,
         }
         return data
 
@@ -1110,6 +1113,7 @@ class DerivedDataApi(metaclass=Singleton):
             am = pd.DataFrame(index_risk[index_col].rolling(window=window,min_periods=min_periods).mean())
             am.columns=['均值']
             df = pd.concat([a1,a2,a3,a4,a5,am],axis=1).sort_index().dropna(axis=0,how='all')
+            df.index.name = 'datetime'
             title = index_name +title_dic[valuation_type]
             data = {
                 'data':df,
@@ -1120,17 +1124,18 @@ class DerivedDataApi(metaclass=Singleton):
             print(f'failed to get data <err_msg> {e} from derived.stock_debt_val_detail')
             return False
 
-    def industry_beta(self):
+    def industry_beta(self,begin_date, end_date, time_para):
         try:
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
             index_info = BasicDataApi().get_asset_info_by_type(['行业指数'])
             index_ids = index_info.real_id.tolist()
-            df = DerivedDataApi().get_index_valuation_develop_without_date(index_ids=index_ids)
+            df = DerivedDataApi().get_index_valuation_develop(index_ids=index_ids,start_date=begin_date,end_date=end_date)
             pb_df = df.pivot_table(index='datetime',values='pb_mrq',columns='index_id')
             roe_df = df.pivot_table(index='datetime',values='roe',columns='index_id')   
             result = []
             dt_list = pb_df.index.tolist()
             for idx, dt, in enumerate(dt_list):
-                if idx % 10 != 0:
+                if idx % 5 != 0:
                     continue
                 _x = roe_df.loc[dt].dropna()
                 x = sm.add_constant(_x)
