@@ -4,6 +4,7 @@ import math
 import json
 import io
 import re
+import datetime
 
 import numpy as np
 import pandas as pd
@@ -442,7 +443,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         df['event_type'] = FOFTradeStatus.DEDUCT_REWARD
         return df
 
-    def upload_custodian_data(self, manager_id: str, fof_id: str, datas: io.BytesIO):
+    def upload_custodian_data(self, manager_id: str, fof_id: str, datas: io.BytesIO) -> datetime.date:
         '''
         上传/更新私募基金托管数据
 
@@ -457,7 +458,7 @@ class HedgeFundDataManager(metaclass=Singleton):
 
         Returns/Exceptions
         -------
-        throw excepion if failed
+        throw excepion if failed, or return a datetime.date if succeed
         '''
 
         to_parse_date = pd.read_excel(datas, skiprows=3, nrows=1).columns.array[0]
@@ -506,14 +507,15 @@ class HedgeFundDataManager(metaclass=Singleton):
         other_assets = interest_receivable + deposit_in_bank
         payable_to_managers = df.at['2206', '市值.1']
         payable_to_custodian = df.at['2207', '市值.1']
+        payable_to_admin_service = 0
+        got_the_item = False
         for subject in ('2215', '2206.14'):
             try:
-                payable_to_admin_service = df.at[subject, '市值.1']
+                payable_to_admin_service += df.at[subject, '市值.1']
+                got_the_item = True
             except KeyError:
                 pass
-            else:
-                break
-        else:
+        if not got_the_item:
             payable_to_admin_service = np.nan
 
         nav = float(df.loc['今日单位净值', '科目名称'])
@@ -553,6 +555,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             for the_id in df.id.dropna().unique():
                 DerivedDataApi().delete_hedge_fund_custodian_data(id_to_delete=the_id)
             df.to_sql(HedgeFundCustodianData.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
+        return the_date
 
     @staticmethod
     def calc_whole_adjusted_net_value(nav_acc_data: pd.DataFrame) -> pd.DataFrame:
