@@ -271,7 +271,7 @@ class HedgeFundNAVReader:
                 elif '卓识佳鑫' in name:
                     df = HedgeFundNAVReader._read_for_ZhuoShiJiaXin(file_path)
                 elif '金锝诚意精心2号' in name:
-                    if not name.endswith('.pdf'):
+                    if '月报' in name or not name.endswith('.pdf'):
                         continue
                     df = HedgeFundNAVReader._read_for_JinDeChengYiJingXin2(file_path)
                 elif '双隆-隆富2号' in name:
