@@ -10,7 +10,7 @@ import os
 from .backtest import FundBacktestEngine
 from .trader import AssetTrader
 from ...data.manager.manager_fund import FundDataManager
-from ...data.struct import AssetTrade, FundTrade, FundScoreParam, TAAParam, TaaTunerParam, AssetTradeParam, AssetWeight
+from ...data.struct import AssetTrade, FundTrade, FundScoreParam, TAAParam, TaaTunerParam, AssetTradeParam, AssetWeight, AssetTimeSpan
 from ...data.api.derived import DerivedDataApi
 from ...data.manager.score import ScoreFunc
 
@@ -244,7 +244,7 @@ class SaaTuner:
             return res
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             print('boom')
             print(f'port_id {port_id} amt_diff {amt_diff}')
             print(saa_dict)    
@@ -396,22 +396,81 @@ class SaaTuner:
 
 class ScoreTuner:
 
+    '''
+    收益能力因子:  alpha ret_over_period treynor m_square annual_ret time_ret alpha_w jensen_alpha_m treynor_ratio_m
+    均衡能力因子:  info_ratio sharpe calmar_ratio_m information_ratio_m sharpe_ratio_m
+    风险能力因子:  beta down_risk mdd var annual_vol beta_w beta_m
+    跟踪能力因子:  track_err track_err_w
+    费用能力因子:  fee_rate
+    '''
+
     INDICATOR_SIGN={
         'alpha':1,
         'beta':-1,
         'fee_rate':-1,
         'track_err':-1,
+        'down_risk':-1,
+        'info_ratio':1,
+        'ret_over_period':1,
+        'treynor':1,
+        'mdd':-1,
+        'm_square':1,
+        'var':-1,
+        'r_square':0, #解释 beta alpha 有效性
+        'sharpe':1,
+        'annual_ret':1,
+        'annual_vol':-1,
+        'time_ret':1,
+        'alpha_w':1,
+        'beta_w':-1,
+        'track_err_w':-1,
+        'beta_m':-1,
+        'calmar_ratio_m':1,
+        'information_ratio_m':1,
+        'jensen_alpha_m':1,
+        'sharpe_ratio_m':1,
+        'treynor_ratio_m':1,
     }
 
     def __init__(self, dm:FundDataManager, index_id:str='national_debt', folder:str='good_luck'):
         self.dm = dm
         self.index_id = index_id
         self.folder = folder
-        self.search_datelist = self.dm.dts.index_fund_indicator_pack.loc[self.index_id].index.levels[0].tolist()
+        self.search_datelist = list(sorted(set(self.dm.dts.index_fund_indicator_pack.loc[self.index_id].index.get_level_values(0).tolist())))
         self.score_list = self.make_score_list()
         self.index_indicator = self.dm.dts.index_fund_indicator_pack.loc[self.index_id]
-        time_span = list(set(self.index_indicator.timespan))[0]
-        self.index_indicator = self.index_indicator[self.index_indicator.year_length > time_span]
+        #time_span = AssetTimeSpan().__dict__[index_id]
+        #self.index_indicator = self.index_indicator[self.index_indicator.year_length > time_span]
+        self.fund_desc_dic = self.dm.dts.fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
+        self.calculate_std()
+
+    def recent_day(self, dt, duration):
+        dts = self.dm.dts.trading_days.datetime
+        dts = dts[dts > dt].values
+        return dts[0], dts[duration]
+
+
+    def make_score_equation(self, score_weight:ScoreFunc=ScoreFunc()):
+        score_dict = {}
+        for indicator, w in score_weight.__dict__.items():
+            if w != 0:
+                if indicator in ['beta', 'beta_w', 'beta_m']:
+                    score_w = self.INDICATOR_SIGN[indicator] * w
+                else:
+                    score_w = self.INDICATOR_SIGN[indicator] * w / getattr(self.indicator_std_mean, indicator)
+                score_i = {indicator: score_w}
+                score_dict.update(score_i)
+        return ScoreFunc(**score_dict)
+
+    def calculate_std(self):
+        dts = self.dm.dts.trading_days.datetime
+        dts = dts[dts > datetime.date(2012,1,1)]
+        fund_indicator_index = self.dm.dts.fund_indicator[self.dm.dts.fund_indicator.index_id == self.index_id]
+        res = []
+        for dt in dts:
+            std_i = fund_indicator_index[fund_indicator_index.datetime == dt].std(ddof=1)
+            res.append(std_i)
+        self.indicator_std_mean = pd.DataFrame(res).mean()
 
     def make_date_param_list(self, time_span:int=242, begin_date=datetime.date(2015,1,1)):
         search_datelist = [_ for _ in self.search_datelist if _ >= begin_date]
@@ -425,6 +484,20 @@ class ScoreTuner:
                 })
         return param_list
 
+    def make_date_param_half_year(self, time_span:int=242, begin_date=datetime.date(2012,1,1), time_lag:int=60):
+        search_datelist = [_ for _ in self.search_datelist if _ >= begin_date]
+        param_list = []
+        for idx,d in enumerate(search_datelist):
+            if idx % time_lag != 0:
+                continue
+            end_idx = time_span + idx
+            if end_idx < len(search_datelist):
+                param_list.append({
+                    'begin_date':d,
+                    'end_date':search_datelist[end_idx]
+                })
+        return param_list
+
     def make_score_list(self):
         score_list = []
         for alpha in np.arange(0,0.8,0.05):
@@ -446,8 +519,9 @@ class ScoreTuner:
         
         index_price = self.dm.dts.index_price.loc[start_date:end_date,[self.index_id]]
         raw_indicator = self.index_indicator.loc[start_date]
-        normalized_indicator = raw_indicator.apply(lambda x: (x - x.mean() + 1e-6)/ (x.std() + 1e-6), axis=0)
-        normalized_indicator['beta'] = raw_indicator['beta']
+        # normalized_indicator = raw_indicator.apply(lambda x: (x - x.mean() + 1e-6)/ (x.std() + 1e-6), axis=0)
+        # normalized_indicator['beta'] = raw_indicator['beta']
+        normalized_indicator = raw_indicator
         score_raw = normalized_indicator.apply(lambda x: score_method.get(x), axis=1)
         select_funds = pd.DataFrame(score_raw).sort_values(0,ascending=False).index[:top_num].tolist()
         select_nav = self.dm.dts.fund_nav.loc[start_date:end_date,select_funds]
@@ -455,6 +529,69 @@ class ScoreTuner:
         index_ret = (index_price.iloc[-1] / index_price.iloc[0]).values[0] - 1
         return funds_mean_ret - index_ret
 
+    def select_fund_checker(self,top_num:int=4, 
+                                start_date:datetime.date=datetime.date(2018,1,1),
+                                end_date:datetime.date=datetime.date(2019,1,1),
+                                score_method:ScoreFunc=ScoreFunc(alpha=0.5/ 0.0444, beta=-0.4, track_err=-0.0/0.03939 ,fee_rate=-0.1/ 0.00266)):
+        index_price = self.dm.dts.index_price.loc[start_date:end_date,[self.index_id]]
+        raw_indicator = self.index_indicator.loc[start_date]
+        normalized_indicator = raw_indicator
+        score_raw = normalized_indicator.apply(lambda x: score_method.get(x), axis=1)
+        select_funds = pd.DataFrame(score_raw).sort_values(0,ascending=False).index[:top_num].tolist()
+        select_fund_desc = [self.fund_desc_dic[i] for i in select_funds] 
+        
+        select_nav = self.dm.dts.fund_nav.loc[start_date:end_date,select_funds]
+        funds_mean_ret =  np.mean(select_nav.iloc[-1] / select_nav.iloc[0]) - 1
+        index_ret = (index_price.iloc[-1] / index_price.iloc[0]).values[0] - 1
+        alpha = funds_mean_ret - index_ret
+        return select_fund_desc, alpha
+    
+    def select_fund_score(self, score_method:ScoreFunc=ScoreFunc(alpha=0.5/ 0.0444, beta=-0.4, track_err=-0.0/0.03939 ,fee_rate=-0.1/ 0.00266)):
+        result = []
+        param_list = self.make_date_param_half_year()
+        for param_i in param_list:
+            desc_name, alpha_i = self.select_fund_checker(
+                            start_date=param_i['begin_date'], 
+                            end_date=param_i['end_date'],
+                            score_method=score_method,
+                            )
+            result.append({
+                'datetime' : param_i['begin_date'],
+                'alpha' : alpha_i,
+                'desc_name': desc_name
+            })
+            
+        alpha_mean = np.mean([i['alpha'] for i in result])
+        select_fund = [i['desc_name'] for i in result]
+        select_fund = [item for sublist in select_fund for item in sublist]
+        power_num = 0
+        link_num = 0
+        for i in select_fund:
+            if '增强' in i:
+                power_num += 1
+            elif '联接' in i:
+                link_num += 1
+        power_rate = power_num / len(select_fund)
+        link_rate = link_num / len(select_fund)
+        dic = {
+            '增强比例':power_rate,
+            '联接比例':link_rate,
+            'alpha':alpha_mean,
+            'score_func':score_method,
+        }
+        return dic
+    
+    def score_maker(self):
+        res = []
+        for alpha in range(15,100,3):
+            for beta in range(15,100,3):
+                fee_rate = 100 - alpha - beta
+                if fee_rate < 0:
+                    continue
+                res.append(ScoreFunc(alpha=alpha/100/0.08291, beta=-beta/100, fee_rate=-fee_rate/100/0.0031)),#csi500
+                #hs300 res.append(ScoreFunc(alpha=alpha/100/0.0444, beta=-beta/100, track_err=-0.0/0.03939 ,fee_rate=-fee_rate/100/0.00266))
+        return res
+
     def score_factor_calculator(self, score_method:ScoreFunc=ScoreFunc(alpha=0.3, beta=-0.6, fee_rate=-0.1),
                                     param_idx:int=1):
         t1 = time.time()
@@ -477,6 +614,41 @@ class ScoreTuner:
         print(f'param_idx {param_idx} finish ,cost time {t2 - t1} s')
         return True
         
+    def score_checker(self):
+        # 日度
+        score_list = []
+        step = 0.10
+        start = 0
+        end = 0.5
+
+        for alpha in np.arange(start,end,step):
+            for beta in np.arange(start,end,step):
+                for ret_over_period in np.arange(start,end,step):
+                    for treynor in np.arange(start,end,step):
+                        for m_square in np.arange(start,end,step):
+                            for annual_ret in np.arange(start,end,step):
+                                for time_ret in np.arange(start,end,step):
+                                    for jensen_alpha_m in np.arange(start,end,step):
+                                        treynor_ratio_m = 1-alpha-beta-ret_over_period-treynor-m_square-annual_ret-time_ret-jensen_alpha_m
+                                        if treynor_ratio_m < 0 or treynor_ratio_m > 0.5:
+                                            continue
+                                        s = ScoreFunc(alpha=alpha,
+                                                beta=beta,
+                                                ret_over_period=ret_over_period,
+                                                treynor=treynor,
+                                                m_square=m_square,
+                                                annual_ret=annual_ret,
+                                                time_ret=time_ret,
+                                                jensen_alpha_m=jensen_alpha_m,
+                                                treynor_ratio_m=treynor_ratio_m)
+                                        score_list.append(self.make_score_equation(s))
+        result = []
+        for score_i in score_list[:50]:
+            res_i = self.select_fund_score(score_i)
+            result.append(res_i)
+            print(score_list.index(score_i)) 
+
+
     def multi_search(self, score_list:list=[ScoreFunc(alpha=0.3, beta=-0.6, fee_rate=-0.1), 
                                             ScoreFunc(alpha=0.3, beta=-0.5, fee_rate=-0.2),
                                             ScoreFunc(alpha=0.2, beta=-0.7, fee_rate=-0.1),
@@ -506,6 +678,10 @@ class ScoreTuner:
             })
         return pd.DataFrame(res)   
 
+
+
+
+
 if __name__ == "__main__":
     
     tt = TaaTunerParam()
