@@ -1021,6 +1021,17 @@ class Calculator:
     @staticmethod
     def get_index_stats(begin_date, end_date, time_para, index_list):
         try:
+            
+            index_info = DerivedDataApi().get_index_val_info()
+            res = []
+            for i in index_info['index_group']:
+                _title = i['title']
+                _items = i['items']
+                for j in _items:
+                    j['title'] = _title
+                    res.append(j)
+            asset_info = pandas.DataFrame(res).set_index('id')
+
             indicator_dics = {
                 'cumu_ret':'区间收益',
                 'annualized_ret':'年化收益',
@@ -1040,6 +1051,7 @@ class Calculator:
                 'est_peg':'预测PEG',
             }
             result = []
+            #asset_info = BasicDataApi().get_asset_info_real(real_id_list=index_list)
             begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
             basic = BasicDataApi()
             index_info = basic.get_index_info(index_list=index_list)
@@ -1051,15 +1063,16 @@ class Calculator:
                 values = df[asset].values
                 dic = Calculator.get_stat_result(dates=dates,values=values).__dict__
                 dic['具体指数'] = index_name[asset]
+                dic['类别'] = asset_info.loc[asset].title
                 dic['index_id'] = asset
                 result.append(dic)
 
             df = pandas.DataFrame(result).set_index('index_id')
             df_val = DerivedDataApi().get_index_valuation_last_date(dt=end_date, index_ids=index_list)
             df_val = df_val.set_index('index_id')
-            df = df[list(indicator_dics.keys())+['具体指数']].rename(columns=indicator_dics)
+            df = df[list(indicator_dics.keys())+['具体指数','类别']].rename(columns=indicator_dics)
             df = df.join(df_val[list(_dic.keys())].rename(columns=_dic))
-            l = ['夏普比率','具体指数','卡玛比率']
+            l = ['夏普比率','具体指数','卡玛比率','类别']
             for col in df:
                 if col not in l and col not in _dic.values():
                     df[col] = (df[col] * 100).round(2)
@@ -1067,7 +1080,7 @@ class Calculator:
                     df[col] = df[col].round(2)
             df['夏普比率'] = df['夏普比率'].round(2)
             df['卡玛比率'] = df['卡玛比率'].round(2)
-            return df.reset_index(drop=True)
+            return df.reset_index()
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from get_index_stats.__tablename__')
             return pandas.DataFrame([])
